@@ -1,7 +1,7 @@
 import ibmcloudsql
 my_bluemix_apikey = 'YNiXREBMTfQsSzKrXYhQJElNXnUFEgpQ7qVVTkDK3_Zr'
 my_instance_crn='crn%3Av1%3Abluemix%3Apublic%3Asql-query%3Aus-south%3Aa%2Fd86af7367f70fba4f306d3c19c938f2f%3Ad1b2c005-e3d8-48c0-9247-e9726a7ed510%3A%3A'
-my_target_cos_url='cos://s3.us-south.objectstorage.softlayer.net/sqltempregional/'
+my_target_cos_url='cos://us-south/sqltempregional/'
 sqlClient = ibmcloudsql.SQLQuery(my_bluemix_apikey, my_instance_crn, my_target_cos_url, client_info='ibmcloudsql test')
 
 print("Running test with individual method invocation:")
